@@ -1,4 +1,6 @@
 test_that("cross-sectional id le 400 binomial", {
+	skip_if_not_installed("SeqArray")
+	skip_if_not_installed("SeqVarTools")
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
 	data(example)
@@ -41,6 +43,8 @@ test_that("cross-sectional id le 400 binomial", {
 
 test_that("cross-sectional id gt 400 binomial", {
 	skip_on_cran()
+	skip_if_not_installed("SeqArray")
+	skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -71,6 +75,8 @@ test_that("cross-sectional id gt 400 binomial", {
 
 test_that("cross-sectional id le 400 gaussian", {
 	skip_on_cran()
+	skip_if_not_installed("SeqArray")
+	skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -100,6 +106,8 @@ test_that("cross-sectional id le 400 gaussian", {
 
 test_that("cross-sectional id gt 400 gaussian", {
 	skip_on_cran()
+	skip_if_not_installed("SeqArray")
+	skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -130,6 +138,8 @@ test_that("cross-sectional id gt 400 gaussian", {
 
 test_that("longitudinal repeated measures gaussian", {
 	skip_on_cran()
+	skip_if_not_installed("SeqArray")
+	skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
@@ -153,6 +163,8 @@ test_that("longitudinal repeated measures gaussian", {
 
 test_that("longitudinal random time trend gaussian", {
 	skip_on_cran()
+	skip_if_not_installed("SeqArray")
+	skip_if_not_installed("SeqVarTools")
 
 	gdsfile <- system.file("extdata", "geno.gds", package = "GMMAT")
 	group.file <- system.file("extdata", "SetID.withweights.txt", package = "GMMAT")
