@@ -28,7 +28,7 @@ test_that("cross-sectional id le 400 binomial", {
 	expect_equal(signif(as.numeric(obj5$theta)), signif(c(1, 0.1925225)))
 	expect_equal(signif(as.numeric(obj5$coef)), signif(c(1.01676230, -0.01506251, -0.33240659)))
 	obj6 <- glmmkin(disease ~ age + sex, data = pheno, kins = NULL, id = "id", family = binomial(link = "logit"), method = "REML", method.optim = "AI")
-	expect_equal(c(obj6$theta), 1)
+	expect_equal(as.numeric(obj6$theta), 1)
 	expect_equal(signif(as.numeric(obj6$coef)), signif(c(0.94253958, -0.01429532, -0.32823930)))
 	obj <- glm(disease ~ age + sex, data = pheno, family = binomial(link = "logit"))
 	expect_equal(obj6$coef, obj$coef)
@@ -109,7 +109,7 @@ test_that("cross-sectional id gt 400 binomial", {
 	expect_equal(signif(as.numeric(obj5$theta)), signif(c(1, 0.1263611)))
 	expect_equal(signif(as.numeric(obj5$coef)), signif(c(0.92300945, -0.01457307, -0.18165858)))
 	obj6 <- glmmkin(disease ~ age + sex, data = pheno, kins = NULL, id = "id", family = binomial(link = "logit"), method = "REML", method.optim = "AI")
-	expect_equal(c(obj6$theta), 1)
+	expect_equal(as.numeric(obj6$theta), 1)
 	expect_equal(signif(as.numeric(obj6$coef)), signif(c(0.86840325, -0.01402939, -0.17898775)))
 	obj <- glm(disease ~ age + sex, data = pheno, family = binomial(link = "logit"))
 	expect_equal(obj6$coef, obj$coef)
@@ -192,7 +192,7 @@ test_that("cross-sectional id le 400 gaussian", {
 	expect_equal(signif(as.numeric(obj6$theta)), signif(1.996857))
 	expect_equal(signif(as.numeric(obj6$coef)), signif(c(3.89665633, 0.03156906, 0.27860778)))
 	obj <- lm(trait ~ age + sex, data = pheno)
-	expect_equal(c(obj6$theta), summary(obj)$sigma^2)
+	expect_equal(as.numeric(obj6$theta), summary(obj)$sigma^2)
 	expect_equal(obj6$coef, obj$coef)
 
 	idx <- sample(nrow(pheno))
@@ -216,7 +216,7 @@ test_that("cross-sectional id le 400 gaussian", {
 	expect_equal(obj6$theta, obj$theta)
 	expect_equal(obj6$coef, obj$coef)
 	obj <- lm(trait ~ age + sex, data = pheno)
-	expect_equal(c(obj6$theta), summary(obj)$sigma^2)
+	expect_equal(as.numeric(obj6$theta), summary(obj)$sigma^2)
 	expect_equal(obj6$coef, obj$coef)
 
 	idx <- sample(nrow(kins))
@@ -275,7 +275,7 @@ test_that("cross-sectional id gt 400 gaussian", {
 	expect_equal(signif(as.numeric(obj6$theta)), signif(2.051809))
 	expect_equal(signif(as.numeric(obj6$coef)), signif(c(3.7836398, 0.0344577, 0.3602852)))
 	obj <- lm(trait ~ age + sex, data = pheno)
-	expect_equal(c(obj6$theta), summary(obj)$sigma^2)
+	expect_equal(as.numeric(obj6$theta), summary(obj)$sigma^2)
 	expect_equal(obj6$coef, obj$coef)
 
 	idx <- sample(nrow(pheno))
@@ -299,7 +299,7 @@ test_that("cross-sectional id gt 400 gaussian", {
 	expect_equal(obj6$theta, obj$theta)
 	expect_equal(obj6$coef, obj$coef)
 	obj <- lm(trait ~ age + sex, data = pheno)
-	expect_equal(c(obj6$theta), summary(obj)$sigma^2)
+	expect_equal(as.numeric(obj6$theta), summary(obj)$sigma^2)
 	expect_equal(obj6$coef, obj$coef)
 
 	idx <- sample(nrow(kins))
